@@ -12,8 +12,7 @@ class Deployment:
     CACHE_REGEX = "\$\((?P<reference>.*?)\)"
 
     def __init__(self, verbose, preview, config, clients):
-        self.cache = collections.defaultdict(
-            lambda: collections.defaultdict(dict))
+        self.cache = (nested_dict := lambda: collections.defaultdict(nested_dict))()
 
         self.config = config
         self.clients = clients
@@ -30,23 +29,28 @@ class Deployment:
             self.execute(action)
 
     def resolve(self, args):
-        return json.loads(re.sub(
-            Deployment.CACHE_REGEX,
-            lambda m: rgetattr(self.cache, m.group(Deployment.MATCH_REF)),
-            json.dumps(args, sort_keys=True)
-        ))
+        return json.loads(
+            re.sub(
+                Deployment.CACHE_REGEX,
+                lambda m: rgetattr(self.cache, m.group(Deployment.MATCH_REF)),
+                json.dumps(args, sort_keys=True),
+            )
+        )
 
+    # e.g. <namespace>.<client>.<fn>.<optional meta tag>
     def execute(self, action):
-        # e.g. <namespace>.<client>.<fn>.<optional meta tag>
-        name, client_name, fn_name, *tag = next(iter(action)).split(".")
-        id = f"{name}.{client_name}.{fn_name}" + (f".{tag[0]}" if tag else "")
+        name, client_name, fn_name = action.split(".")
+        id = f"{name}.{client_name}.{fn_name}"
 
         if self.verbose:
             print(f"{Colors.OKCYAN}{id}{Colors.ENDC}")
 
         try:
-            fn = rgetattr(self.clients, f"{client_name}.{fn_name}")
-            args = self.resolve(next(iter(action.values())))
+            fn = rgetattr(
+                self.clients,
+                fn_name if client_name == "user" else f"{client_name}.{fn_name}",
+            )
+            args = self.resolve(self.config[action])
 
             if self.verbose:
                 self.print_status(args, Colors.OKBLUE, "→")
@@ -74,12 +78,16 @@ class Deployment:
 
     def summarize(self, actions):
         for action in actions:
-            print(f"{Colors.OKCYAN}{next(iter(action))}{Colors.ENDC}")
-            self.print_status(action, Colors.OKBLUE, "→")
+            print(f"{Colors.OKCYAN}{action}{Colors.ENDC}")
+            self.print_status(self.config[action], Colors.OKBLUE, "→")
 
         print()
 
     def print_status(self, value, status, indicator):
-        print(textwrap.indent(json.dumps(value, indent=2, default=str),
-                              f"{status}{indicator} {Colors.ENDC}",
-                              lambda _: True))
+        print(
+            textwrap.indent(
+                json.dumps(value, indent=2, default=str),
+                f"{status}{indicator} {Colors.ENDC}",
+                lambda _: True,
+            )
+        )
